From 24ad50286a87833329213dc0b0e68c21aeeee95f Mon Sep 17 00:00:00 2001
From: Niko Mauno <niko.mauno@vaisala.com>
Date: Wed, 22 Apr 2020 09:00:00 +0300
Subject: [PATCH] CMakeLists.txt: Avoid host-specific path to libsodium

Avoid propagating full build host specific path to generated
ZeroMQTargets.cmake when building with libsodium, which changes the
content in generated ZeroMQTargets.cmake files followingly:

  -INTERFACE_LINK_LIBRARIES "-lpthread;/build/host/specific/path/to/zeromq/4.3.2-r0/recipe-sysroot/usr/lib/libsodium.so;-lrt"
  +INTERFACE_LINK_LIBRARIES "-lpthread;-lsodium;-lrt"

This change mitigates an issue stemming from reuse of build artifacts
where the path to libsodium.so does not match exactly between two
different build hosts.

Upstream-Status: Pending

Signed-off-by: Niko Mauno <niko.mauno@vaisala.com>

---
 CMakeLists.txt | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index e92141d..d0775c1 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -1428,7 +1428,7 @@ if(BUILD_SHARED)
   endif()
 
   if(SODIUM_FOUND)
-    target_link_libraries(libzmq ${SODIUM_LIBRARIES})
+    target_link_libraries(libzmq -lsodium)
     # On Solaris, libsodium depends on libssp
     if(${CMAKE_SYSTEM_NAME} MATCHES "SunOS")
       target_link_libraries(libzmq ssp)
@@ -1473,7 +1473,7 @@ if(BUILD_STATIC)
   endif()
 
   if(SODIUM_FOUND)
-    target_link_libraries(libzmq-static ${SODIUM_LIBRARIES})
+    target_link_libraries(libzmq-static -lsodium)
     # On Solaris, libsodium depends on libssp
     if(${CMAKE_SYSTEM_NAME} MATCHES "SunOS")
       target_link_libraries(libzmq-static ssp)
